use crate::{revision::Revision, BuildDirective};

#[derive(serde::Deserialize)]
struct Release {
    tag_name: String,
}

pub(crate) async fn check_github_release(
    namespace: String,
    repository: String,
    previous_revision: &Revision,
) -> color_eyre::eyre::Result<BuildDirective> {
    let github_client = reqwest::Client::builder()
        .user_agent("release-checker (+https://git.asonix.dog/asonix/release-checker)")
        .build()?;

    let url = format!(
        "https://api.github.com/repos/{}/{}/releases",
        namespace, repository,
    );

    let releases: Vec<Release> = github_client
        .get(url)
        .header("Accept", "application/vnd.github.v3+json")
        .send()
        .await?
        .json()
        .await?;

    if let Some(release) = releases.get(0) {
        if release.tag_name.trim_start_matches('v')
            == previous_revision.version.trim_start_matches('v')
        {
            return Ok(BuildDirective::ShouldIgnore);
        }
        return Ok(BuildDirective::ShouldBuild(Some(release.tag_name.clone())));
    }

    Ok(BuildDirective::ShouldIgnore)
}
